import { Logger } from '../logger';
import { z } from 'zod';
import { WorkflowLogMessage, StepDefinition } from './types';
export declare class Workflow<TTrigger = any, TSteps extends Record<string, StepDefinition<any, any>> = Record<string, StepDefinition<any, any>>> {
    #private;
    name: string;
    triggerSchema?: z.ZodType<any>;
    /**
     * Creates a new Workflow instance
     * @param name - Identifier for the workflow (not necessarily unique)
     * @param logger - Optional logger instance
     */
    constructor(name: string, logger?: Logger<WorkflowLogMessage>);
    /**
     * Initializes the XState machine for the workflow
     *
     * Registers the machine's types, actions, actors, initial context, entry actions, initial state, and states
     * @returns The initialized machine
     */
    private initializeMachine;
    /**
     * Rebuilds the machine with the current steps configuration and validates the workflow
     *
     * This is the last step of a workflow builder method chain
     * @throws Error if validation fails
     */
    commit(): void;
    /**
     * Sets the schema for validating trigger data
     * @param schema - Zod schema for trigger data validation
     * @returns this instance for method chaining
     */
    setTriggerSchema(schema: z.ZodType<any>): this;
    /**
     * Adds a new step to the workflow
     * @param id - Unique identifier for the step
     * @param config - Step configuration including handler, schema, variables, and payload
     * @returns this instance for method chaining (builder pattern baybyyyy)
     * @throws Error if step ID is duplicate or variable resolution fails
     */
    addStep<TSchema extends z.ZodType<any>, TOutput = any, TTransitions extends string = string>(id: string, config: StepDefinition<TSchema, TOutput, TTransitions>): Workflow<TTrigger, TSteps & Record<typeof id, typeof config>>;
    /**
     * Executes the workflow with the given trigger data
     * @param triggerData - Initial data to start the workflow with
     * @returns Promise resolving to workflow results or rejecting with error
     * @throws Error if trigger schema validation fails
     */
    executeWorkflow<TSchema = unknown, TTrigger = this['triggerSchema'] extends z.ZodSchema<infer T> ? T : TSchema>(triggerData?: TTrigger): Promise<{
        triggerData?: TTrigger;
        results: Record<string, unknown>;
    }>;
}
//# sourceMappingURL=main.d.ts.map